package com.tzld.piaoquan.recommend.feature.service;

import com.google.common.base.Strings;
import com.tzld.piaoquan.recommend.feature.model.*;
import com.tzld.piaoquan.recommend.feature.model.feature.*;

/**
 * @author dyp
 */
public class FeatureConverter {
    public static UserFeatureProto convert(UserFeature userFeature) {
        if (userFeature == null) {
            return null;
        }
        UserFeatureProto.Builder builder = UserFeatureProto.newBuilder();
        builder.setUid(Strings.nullToEmpty(userFeature.getUid()))
                .setUserCycleBucket7Day(Strings.nullToEmpty(userFeature.getUser_cycle_bucket_7days()))
                .setUserCycleBucket30Day(Strings.nullToEmpty(userFeature.getUser_cycle_bucket_30days()))
                .setUserShareBucket30Day(Strings.nullToEmpty(userFeature.getUser_share_bucket_30days()));

        if (userFeature.getDay1_cnt_features() != null) {
            builder.setDay1CntFeature(convert(userFeature.getDay1_cnt_features()));
        }
        if (userFeature.getDay3_cnt_features() != null) {
            builder.setDay3CntFeature(convert(userFeature.getDay3_cnt_features()));
        }
        if (userFeature.getDay7_cnt_features() != null) {
            builder.setDay7CntFeature(convert(userFeature.getDay7_cnt_features()));
        }
        if (userFeature.getMonth3_cnt_features() != null) {
            builder.setMonth3CntFeature(convert(userFeature.getMonth3_cnt_features()));
        }

        return builder.build();
    }

    private static UserActionFeatureProto convert(UserActionFeature feature) {
        if (feature == null) {
            return null;
        }
        UserActionFeatureProto.Builder builder = UserActionFeatureProto.newBuilder();
        builder.setCtr(feature.getCtr())
                .setStr(feature.getStr())
                .setRov(feature.getRov())
                .setShareCnt(Math.round(feature.getShare_cnt()))
                .setReturnCnt(Math.round(feature.getReturn_cnt()))
                .setClickCnt(Math.round(feature.getClick_cnt()))
                .setExpCnt(Math.round(feature.getExp_cnt()));

        return builder.build();
    }


    public static VideoFeatureProto convert(VideoFeature videoFeature) {
        if (videoFeature == null) {
            return null;
        }
        VideoFeatureProto.Builder builder = VideoFeatureProto.newBuilder();

        builder.setVideoId(Strings.nullToEmpty(videoFeature.getVideoId()))
                .setUpId(Strings.nullToEmpty(videoFeature.getUpId()))
                .setTags(Strings.nullToEmpty(videoFeature.getTags()))
                .setPlayLength(Strings.nullToEmpty(videoFeature.getPlayLength()))
                .setTotalTime(Strings.nullToEmpty(videoFeature.getTotalTime()))
                .setDaysSinceUpload(Strings.nullToEmpty(videoFeature.getDaysSinceUpload()));

        if (videoFeature.getDay1_cnt_features() != null) {
            builder.setVideoDay1CntFeature(convert(videoFeature.getDay1_cnt_features()));
        }
        if (videoFeature.getDay3_cnt_features() != null) {
            builder.setVideoDay3CntFeature(convert(videoFeature.getDay3_cnt_features()));
        }
        if (videoFeature.getDay7_cnt_features() != null) {
            builder.setVideoDay7CntFeature(convert(videoFeature.getDay7_cnt_features()));
        }
        if (videoFeature.getMonth3_cnt_features() != null) {
            builder.setVideoMonth3CntFeature(convert(videoFeature.getMonth3_cnt_features()));
        }

        return builder.build();
    }

    public static UserAdFeatureProto convertToProto(UserAdFeature userAdFeature) {
        UserAdFeatureProto.Builder builder = UserAdFeatureProto.newBuilder();
        builder.setMid(userAdFeature.getMid());
        builder.setGender(userAdFeature.getGender());
        builder.setUserType(userAdFeature.getUser_type());
        builder.setGmtCreate(userAdFeature.getGmt_create());
        builder.setTags(userAdFeature.getTags());
        builder.setCategoryName(userAdFeature.getCategory_name());
        builder.setIsvip(userAdFeature.getIsvip());
        builder.setIsreward(userAdFeature.getIsreward());
        builder.setIsad(userAdFeature.getIsad());
        builder.setIsgood(userAdFeature.getIsgood());
        builder.setFirstUpDatetime(userAdFeature.getFirst_up_datetime());
        builder.setLastUpDatetime(userAdFeature.getLast_up_datetime());
        builder.setNextToLastUpDatetime(userAdFeature.getNext_to_last_up_datetime());
        builder.setVideos(userAdFeature.getVideos());
        builder.setIdols(userAdFeature.getIdols());
        builder.setFans(userAdFeature.getFans());
        builder.setPlayCount(userAdFeature.getPlay_count());
        builder.setPlayCountTotal(userAdFeature.getPlay_count_total());
        builder.setTotalReward(userAdFeature.getTotal_reward());
        builder.setCurrentdayReward(userAdFeature.getCurrentday_reward());
        builder.setRewardPerson(userAdFeature.getReward_person());
        builder.setTotalRewardTimes(userAdFeature.getTotal_reward_times());
        builder.setRewardVideos(userAdFeature.getReward_videos());
        builder.setTotalPrice(userAdFeature.getTotal_price());
        builder.setCurrentdayPrice(userAdFeature.getCurrentday_price());
        builder.setTotalPriceTimes(userAdFeature.getTotal_price_times());
        builder.setTotalPricePerson(userAdFeature.getTotal_price_person());
        builder.setTotalPriceVideos(userAdFeature.getTotal_price_videos());
        builder.setCgrainUserType(userAdFeature.getCgrain_user_type());
        builder.setIdentityTagname(userAdFeature.getIdentity_tagname());
        builder.setOperationTags(userAdFeature.getOperation_tags());
        builder.setIdentityTagId(userAdFeature.getIdentity_tag_id());
        builder.setIdentityCreateTime(userAdFeature.getIdentity_create_time());
        builder.setCountry(userAdFeature.getCountry());
        builder.setProvince(userAdFeature.getProvince());
        builder.setCity(userAdFeature.getCity());

        builder.setDay1CntFeatures(convertToProto(userAdFeature.getDay1_cnt_features()));
        builder.setDay3CntFeatures(convertToProto(userAdFeature.getDay3_cnt_features()));
        builder.setDay7CntFeatures(convertToProto(userAdFeature.getDay7_cnt_features()));
        builder.setMonth3CntFeatures(convertToProto(userAdFeature.getMonth3_cnt_features()));

        return builder.build();
    }

    public static AdActionFeatureProto convertToProto(AdActionFeature adActionFeature) {
        AdActionFeatureProto.Builder builder = AdActionFeatureProto.newBuilder();
        builder.setAdView(adActionFeature.getAdView());
        builder.setAdClick(adActionFeature.getAdClick());
        builder.setAdConversion(adActionFeature.getAdConversion());
        builder.setCtr(adActionFeature.getCtr());
        builder.setCvr(adActionFeature.getCvr());
        return builder.build();
    }

    public static AdItemFeatureProto convertToProto(AdItemFeature adItemFeature) {
        AdItemFeatureProto.Builder builder = AdItemFeatureProto.newBuilder();
        builder.setAdId(adItemFeature.getAdId());
        builder.setAdCode(adItemFeature.getAdCode());
        builder.setAdvertiserId(adItemFeature.getAdvertiserId());
        builder.setAdvertiserCode(adItemFeature.getAdvertiserCode());
        builder.setCampaignId(adItemFeature.getCampaignId());
        builder.setCampaignCode(adItemFeature.getCampaignCode());
        builder.setCreativeId(adItemFeature.getCreativeId());
        builder.setCreativeCode(adItemFeature.getCreativeCode());
        builder.setDay1CntFeatures(convertToProto(adItemFeature.getDay1_cnt_features()));
        builder.setDay3CntFeatures(convertToProto(adItemFeature.getDay3_cnt_features()));
        builder.setDay7CntFeatures(convertToProto(adItemFeature.getDay7_cnt_features()));
        builder.setMonth3CntFeatures(convertToProto(adItemFeature.getMonth3_cnt_features()));
        return builder.build();
    }
}
